##  Enabling OData Sharing for a Saved Search
To export fact sheet data to external systems, enable OData sharing for a saved search. Note the following:
  * You can enable OData sharing only for saved searches created within the table view. Only the columns that you selected when creating a saved search are exported through OData.
  * Avoid using the dot (.) and the @ symbol in the column names because this interferes with the annotations in OData.
  * When the saved search permission is set to Read & Write Restricted, OData sharing is disabled for this saved search.


To enable OData sharing for a saved search, follow these steps:
  1. In the Inventory, navigate to the Searches tab in the left sidebar, then click Manage Searches at the bottom of the sidebar.
![Navigating to Saved Searches from the Inventory](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27420f187a441014843e9437f868d4de_LowRes.png)
Navigating to Saved Searches from the Inventory
  2. On the Manage Saved Searches page, hover over the saved search that you want to update, then click Edit.
![Navigating to the Configuration of a Saved Search](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744b9867a441014b79ad64c960a8dfa_LowRes.png)
Navigating to the Configuration of a Saved Search
  3. On the saved search configuration page, select OData sharing enabled, then click Save.
![Enabling OData Sharing for a Saved Search](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747003d7a44101485f0bd8c0c9c0c70_LowRes.png)
Enabling OData Sharing for a Saved Search


The link icon in the OData column on the Manage Saved Searches page indicates that OData sharing is enabled for a saved search.
![Viewing the Status of](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274cc9b87a441014bbc9d2dddef8eccb_LowRes.png)
Viewing the Status of "OData Sharing Enabled" Option on the "Manage Saved Searches" Page
